@@ -9,7 +9,7 @@
  */
 /*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2018 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2020 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -39,10 +39,10 @@ typedef struct {
     out_stack_t * pOutDesc;
 } tSuspendName;
 
-static int            suspendCt   = 0;
-static int            suspAllocCt = 0;
-static tSuspendName * pSuspended  = NULL;
-static int            outputDepth = 1;
+ static int            suspendCt   = 0;
+ static int            suspAllocCt = 0;
+ static tSuspendName * pSuspended  = NULL;
+ static int            outputDepth = 1;
 
 /**
  * return the current line number
@@ -100,7 +100,7 @@ do_output_file_line(int line_delta, char const * fmt)
 /**
  * chmod a-w on a file descriptor.
  */
-LOCAL void
+static void
 make_readonly(void)
 {
 #if defined(HAVE_FSTAT) || defined(HAVE_FCHMOD)
@@ -146,7 +146,7 @@ make_readonly(void)
 /**
  * Some common code for creating a new file
  */
-LOCAL void
+static void
 open_output_file(char const * fname, size_t nmsz, char const * mode, int flags)
 {
     char *    pz;
@@ -251,7 +251,8 @@ ag_scm_out_move(SCM new_file)
 
     if (strcmp(pz, cur_fpstack->stk_fname) != 0) {
 
-        rename(cur_fpstack->stk_fname, pz);
+        if (rename(cur_fpstack->stk_fname, pz) != 0)
+            fserr(AUTOGEN_EXIT_FS_ERROR, "rename", pz);
 
         if (dep_fp != NULL) {
             rm_target_file(cur_fpstack->stk_fname);
@@ -310,7 +311,7 @@ ag_scm_out_pop(SCM ret_contents)
                 AG_CANT(SCM_OUT_POP_NO_REREAD, cur_fpstack->stk_fname);
         }
 
-        res = scm_from_latin1_stringn(pz, (size_t)pos);
+        res = AG_SCM_FROM_STRN(pz, (size_t)pos);
     }
 
     outputDepth--;
@@ -386,7 +387,7 @@ ag_scm_out_suspend(SCM susp_nm)
                          suspAllocCt * sizeof(tSuspendName), "add to susp f");
     }
 
-    pSuspended[ suspendCt-1 ].pzSuspendName = scm_to_latin1_string(susp_nm);
+    pSuspended[ suspendCt-1 ].pzSuspendName = AG_SCM_TO_STR(susp_nm);
     pSuspended[ suspendCt-1 ].pOutDesc      = cur_fpstack;
     if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
         fprintf(trace_fp, TRACE_SUSPEND, __func__, cur_fpstack->stk_fname,
