@@ -4,8 +4,12 @@
  *
  *  This module implements the CASE text function.
  *
+ * @addtogroup autogen
+ * @{
+ */
+/*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2020 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -21,9 +25,6 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#undef  IS_LOW
-#define IS_LOW(c)  (((c) <= 'z') && ((c) >= 'a'))
-
 #ifndef _toupper
 #  ifdef __toupper
 #    define _toupper(c)     __toupper(c)
@@ -32,10 +33,8 @@
 #  endif
 #endif
 
-#define PTRUP(p) STMTS(if(IS_LOW(*(p))) *(p)=_toupper(*(p));(p)++)
-
 typedef tSuccess (tSelectProc)(char const * sample, char const * pattern);
-static tSelectProc
+MOD_LOCAL tSelectProc
     Select_Compare,
     Select_Compare_End,
     Select_Compare_Start,
@@ -58,98 +57,40 @@ static tSelectProc
  */
 typedef struct case_stack tCaseStack;
 struct case_stack {
-    macro_t*  pCase;
-    macro_t*  pSelect;
+    macro_t *  pCase;
+    macro_t *  pSelect;
 };
 
-static tCaseStack current_case;
-static load_proc_t  mLoad_Select;
+MOD_LOCAL tCaseStack    current_case;
+MOD_LOCAL load_proc_t   mLoad_Select;
 
-static load_proc_p_t apCaseLoad[ FUNC_CT ]   = { NULL };
-static load_proc_p_t apSelectOnly[ FUNC_CT ] = { NULL };
-
-/* = = = START-STATIC-FORWARD = = = */
-static void
-compile_re(regex_t* pRe, char const * pzPat, int flags);
-
-static inline void
-up_case(char* pz);
-
-static tSuccess
-Select_Compare(char const * sample, char const * pattern);
-
-static tSuccess
-Select_Compare_End(char const * sample, char const * pattern);
-
-static tSuccess
-Select_Compare_Start(char const * sample, char const * pattern);
-
-static tSuccess
-Select_Compare_Full(char const * sample, char const * pattern);
-
-static tSuccess
-Select_Equivalent(char const * sample, char const * pattern);
-
-static tSuccess
-Select_Equivalent_End(char const * sample, char const * pattern);
-
-static tSuccess
-Select_Equivalent_Start(char const * sample, char const * pattern);
-
-static tSuccess
-Select_Equivalent_Full(char const * sample, char const * pattern);
-
-static tSuccess
-Select_Match(char const * sample, char const * pattern);
-
-static tSuccess
-Select_Match_End(char const * sample, char const * pattern);
-
-static tSuccess
-Select_Match_Start(char const * sample, char const * pattern);
-
-static tSuccess
-Select_Match_Full(char const * sample, char const * pattern);
-
-static tSuccess
-Select_Match_Always(char const * sample, char const * pattern);
-
-static tSuccess
-Select_Match_Existence(char const * sample, char const * pattern);
-
-static tSuccess
-Select_Match_NonExistence(char const * sample, char const * pattern);
-
-static bool
-selection_type_complete(templ_t * tpl, macro_t * mac, char const ** psrc);
-
-static macro_t *
-mLoad_Select(templ_t * tpl, macro_t * mac, char const ** pscan);
-/* = = = END-STATIC-FORWARD = = = */
+MOD_LOCAL load_proc_p_t apCaseLoad[ FUNC_CT ]   = { NULL };
+MOD_LOCAL load_proc_p_t apSelectOnly[ FUNC_CT ] = { NULL };
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 static void
-compile_re(regex_t* pRe, char const * pzPat, int flags)
+compile_re(regex_t * re, char const * pat, int flags)
 {
-    void * const pat = (void *)pzPat;
-    int  rerr = regcomp(pRe, pat, flags);
+    int rerr = regcomp(re, VOIDP(pat), flags);
     if (rerr != 0) {
-        char zEr[ SCRIBBLE_SIZE ];
-        regerror(rerr, pRe, zEr, sizeof(zEr));
-        fprintf(stderr, BAD_RE_FMT, rerr, zEr, pzPat);
+        char erbf[ SCRIBBLE_SIZE ];
+        regerror(rerr, re, erbf, sizeof(erbf));
+        fprintf(stderr, BAD_RE_FMT, rerr, erbf, pat);
         AG_ABEND(COMPILE_RE_BAD);
     }
 }
 
-
 static inline void
-up_case(char* pz)
+up_case(char * pz)
 {
-    while (*pz != NUL) PTRUP(pz);
+    while (*pz != NUL) {
+        if (IS_LOWER_CASE_CHAR(*pz))
+            *pz = (char)_toupper((int)*pz);
+        pz++;
+    }
 }
 
-
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*=gfunc string_contains_p
@@ -173,8 +114,8 @@ Select_Compare(char const * sample, char const * pattern)
 SCM
 ag_scm_string_contains_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars(text, "text to match");
-    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    char * pzText   = ag_scm2zchars(text, "text to match");
+    char * pzSubstr = ag_scm2zchars(substr, "match expr");
 
     return (strstr(pzText, pzSubstr) == NULL) ? SCM_BOOL_F : SCM_BOOL_T;
 }
@@ -212,8 +153,8 @@ Select_Compare_End(char const * sample, char const * pattern)
 SCM
 ag_scm_string_ends_with_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars(text, "text to match");
-    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    char * pzText   = ag_scm2zchars(text, "text to match");
+    char * pzSubstr = ag_scm2zchars(substr, "match expr");
     return (SUCCESSFUL(Select_Compare_End(pzText, pzSubstr)))
         ? SCM_BOOL_T : SCM_BOOL_F;
 }
@@ -248,8 +189,8 @@ Select_Compare_Start(char const * sample, char const * pattern)
 SCM
 ag_scm_string_starts_with_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars(text, "text to match");
-    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    char * pzText   = ag_scm2zchars(text, "text to match");
+    char * pzSubstr = ag_scm2zchars(substr, "match expr");
     return (SUCCESSFUL(Select_Compare_Start(pzText, pzSubstr)))
         ? SCM_BOOL_T : SCM_BOOL_F;
 }
@@ -277,8 +218,8 @@ Select_Compare_Full(char const * sample, char const * pattern)
 SCM
 ag_scm_string_equals_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars(text, "text to match");
-    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    char * pzText   = ag_scm2zchars(text, "text to match");
+    char * pzSubstr = ag_scm2zchars(substr, "match expr");
 
     return (strcmp(pzText, pzSubstr) == 0) ? SCM_BOOL_T : SCM_BOOL_F;
 }
@@ -303,13 +244,13 @@ ag_scm_string_equals_p(SCM text, SCM substr)
 static tSuccess
 Select_Equivalent(char const * sample, char const * pattern)
 {
-    char*    pz;
+    char *   pz;
     tSuccess res = SUCCESS;
     AGDUPSTR(pz, sample, "equiv chars");
     up_case(pz);
     if (strstr(pz, pattern) == NULL)
         res = FAILURE;
-    AGFREE((void*)pz);
+    AGFREE(pz);
 
     return res;
 }
@@ -327,7 +268,7 @@ ag_scm_string_contains_eqv_p(SCM text, SCM substr)
                                      pzSubstr)))
          res = SCM_BOOL_T;
     else res = SCM_BOOL_F;
-    AGFREE((void*)pzSubstr);
+    AGFREE(pzSubstr);
     return res;
 }
 
@@ -362,8 +303,8 @@ Select_Equivalent_End(char const * sample, char const * pattern)
 SCM
 ag_scm_string_ends_eqv_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars(text, "text to match");
-    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    char * pzText   = ag_scm2zchars(text, "text to match");
+    char * pzSubstr = ag_scm2zchars(substr, "match expr");
     return (SUCCESSFUL(Select_Equivalent_End( pzText, pzSubstr )))
         ? SCM_BOOL_T : SCM_BOOL_F;
 }
@@ -395,8 +336,8 @@ Select_Equivalent_Start(char const * sample, char const * pattern)
 SCM
 ag_scm_string_starts_eqv_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars(text, "text to match");
-    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    char * pzText   = ag_scm2zchars(text, "text to match");
+    char * pzSubstr = ag_scm2zchars(substr, "match expr");
     return (SUCCESSFUL(Select_Equivalent_Start(pzText, pzSubstr)))
         ? SCM_BOOL_T : SCM_BOOL_F;
 }
@@ -495,13 +436,13 @@ Select_Match(char const * sample, char const * pattern)
      *  On the first call for this macro, compile the expression
      */
     if (cur_macro->md_pvt == NULL) {
-        void *    mat = (void *)pattern;
-        regex_t*  pRe = AGALOC(sizeof(*pRe), "select match re");
-        compile_re(pRe, mat, (int)cur_macro->md_res);
-        cur_macro->md_pvt = (void*)pRe;
+        void *    mat = VOIDP(pattern);
+        regex_t * re  = AGALOC(sizeof(*re), "select match re");
+        compile_re(re, mat, (int)cur_macro->md_res);
+        cur_macro->md_pvt = VOIDP(re);
     }
 
-    if (regexec((regex_t*)cur_macro->md_pvt, sample, (size_t)0,
+    if (regexec((regex_t *)cur_macro->md_pvt, sample, (size_t)0,
                  NULL, 0) != 0)
         return FAILURE;
     return SUCCESS;
@@ -527,8 +468,8 @@ ag_scm_string_has_match_p(SCM text, SCM substr)
 SCM
 ag_scm_string_has_eqv_match_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars(text, "text to match");
-    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    char * pzText   = ag_scm2zchars(text, "text to match");
+    char * pzSubstr = ag_scm2zchars(substr, "match expr");
     SCM      res;
     regex_t  re;
 
@@ -578,13 +519,13 @@ Select_Match_End(char const * sample, char const * pattern)
      *  On the first call for this macro, compile the expression
      */
     if (cur_macro->md_pvt == NULL) {
-        void *    mat = (void *)pattern;
-        regex_t*  pRe = AGALOC(sizeof(*pRe), "select match end re");
-        compile_re(pRe, mat, (int)cur_macro->md_res);
-        cur_macro->md_pvt = (void*)pRe;
+        void *    mat = VOIDP(pattern);
+        regex_t * re  = AGALOC(sizeof(*re), "select match end re");
+        compile_re(re, mat, (int)cur_macro->md_res);
+        cur_macro->md_pvt = VOIDP(re);
     }
 
-    if (regexec((regex_t*)cur_macro->md_pvt, sample, (size_t)2, m, 0)
+    if (regexec((regex_t *)cur_macro->md_pvt, sample, (size_t)2, m, 0)
         != 0)
         return FAILURE;
     if (m[0].rm_eo != (int)strlen(sample))
@@ -595,8 +536,8 @@ Select_Match_End(char const * sample, char const * pattern)
 SCM
 ag_scm_string_end_match_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars(text, "text to match");
-    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    char * pzText   = ag_scm2zchars(text, "text to match");
+    char * pzSubstr = ag_scm2zchars(substr, "match expr");
     SCM        res;
     regex_t    re;
     regmatch_t m[2];
@@ -617,8 +558,8 @@ ag_scm_string_end_match_p(SCM text, SCM substr)
 SCM
 ag_scm_string_end_eqv_match_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars(text, "text to match");
-    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    char * pzText   = ag_scm2zchars(text, "text to match");
+    char * pzSubstr = ag_scm2zchars(substr, "match expr");
     SCM        res;
     regex_t    re;
     regmatch_t m[2];
@@ -672,13 +613,13 @@ Select_Match_Start(char const * sample, char const * pattern)
      *  On the first call for this macro, compile the expression
      */
     if (cur_macro->md_pvt == NULL) {
-        void *    mat = (void *)pattern;
-        regex_t*  pRe = AGALOC(sizeof(*pRe), "select match start re");
-        compile_re(pRe, mat, (int)cur_macro->md_res);
-        cur_macro->md_pvt = (void*)pRe;
+        void *    mat = VOIDP(pattern);
+        regex_t * re  = AGALOC(sizeof(*re), "select match start re");
+        compile_re(re, mat, (int)cur_macro->md_res);
+        cur_macro->md_pvt = VOIDP(re);
     }
 
-    if (regexec((regex_t*)cur_macro->md_pvt, sample, (size_t)2, m, 0)
+    if (regexec((regex_t *)cur_macro->md_pvt, sample, (size_t)2, m, 0)
         != 0)
         return FAILURE;
     if (m[0].rm_so != 0)
@@ -689,8 +630,8 @@ Select_Match_Start(char const * sample, char const * pattern)
 SCM
 ag_scm_string_start_match_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars(text, "text to match");
-    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    char * pzText   = ag_scm2zchars(text, "text to match");
+    char * pzSubstr = ag_scm2zchars(substr, "match expr");
     SCM        res;
     regex_t    re;
     regmatch_t m[2];
@@ -711,8 +652,8 @@ ag_scm_string_start_match_p(SCM text, SCM substr)
 SCM
 ag_scm_string_start_eqv_match_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars(text, "text to match");
-    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    char * pzText   = ag_scm2zchars(text, "text to match");
+    char * pzSubstr = ag_scm2zchars(substr, "match expr");
     SCM        res;
     regex_t    re;
     regmatch_t m[2];
@@ -768,18 +709,18 @@ Select_Match_Full(char const * sample, char const * pattern)
      *  On the first call for this macro, compile the expression
      */
     if (cur_macro->md_pvt == NULL) {
-        void *    mat = (void *)pattern;
-        regex_t*  pRe = AGALOC(sizeof(*pRe), "select match full re");
+        void *    mat = VOIDP(pattern);
+        regex_t * re  = AGALOC(sizeof(*re), "select match full re");
 
         if (OPT_VALUE_TRACE > TRACE_EXPRESSIONS) {
             fprintf(trace_fp, TRACE_SEL_MATCH_FULL,
                      pattern, cur_macro->md_res);
         }
-        compile_re(pRe, mat, (int)cur_macro->md_res);
-        cur_macro->md_pvt = pRe;
+        compile_re(re, mat, (int)cur_macro->md_res);
+        cur_macro->md_pvt = re;
     }
 
-    if (regexec((regex_t*)cur_macro->md_pvt, sample, (size_t)2, m, 0)
+    if (regexec((regex_t *)cur_macro->md_pvt, sample, (size_t)2, m, 0)
         != 0)
         return FAILURE;
 
@@ -792,8 +733,8 @@ Select_Match_Full(char const * sample, char const * pattern)
 SCM
 ag_scm_string_match_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars(text, "text to match");
-    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    char * pzText   = ag_scm2zchars(text, "text to match");
+    char * pzSubstr = ag_scm2zchars(substr, "match expr");
     SCM        res;
     regex_t    re;
     regmatch_t m[2];
@@ -815,8 +756,8 @@ ag_scm_string_match_p(SCM text, SCM substr)
 SCM
 ag_scm_string_eqv_match_p(SCM text, SCM substr)
 {
-    char* pzText   = ag_scm2zchars(text, "text to match");
-    char* pzSubstr = ag_scm2zchars(substr, "match expr");
+    char * pzText   = ag_scm2zchars(text, "text to match");
+    char * pzSubstr = ag_scm2zchars(substr, "match expr");
     SCM        res;
     regex_t    re;
     regmatch_t m[2];
@@ -951,7 +892,7 @@ Select_Match_NonExistence(char const * sample, char const * pattern)
  *    For a complete description, @xref{CASE}.
 =*/
 macro_t *
-mFunc_Case(templ_t* pT, macro_t* pMac)
+mFunc_Case(templ_t * pT, macro_t * pMac)
 {
     typedef tSuccess (t_match_proc)(char const *, char const *);
     /*
@@ -1058,7 +999,7 @@ mFunc_Case(templ_t* pT, macro_t* pMac)
     }
 
     if (free_txt)
-        AGFREE((void*)samp_text);
+        AGFREE(samp_text);
 
     return end_mac;
 }
@@ -1070,11 +1011,11 @@ mFunc_Case(templ_t* pT, macro_t* pMac)
  *  when the template is first read in (before processing).
  */
 macro_t *
-mLoad_Case(templ_t* pT, macro_t* pMac, char const ** ppzScan)
+mLoad_Case(templ_t * pT, macro_t * pMac, char const ** ppzScan)
 {
     size_t         srcLen     = (size_t)pMac->md_res;   /* macro len  */
     tCaseStack     save_stack = current_case;
-    macro_t*        pEsacMac;
+    macro_t *      pEsacMac;
 
     /*
      *  Save the global macro loading mode
@@ -1109,7 +1050,7 @@ mLoad_Case(templ_t* pT, macro_t* pMac, char const ** ppzScan)
         for (i=0; i < FUNC_CT; i++)
             apSelectOnly[i] = mLoad_Bogus;
 
-        memcpy((void*)apCaseLoad, base_load_table, sizeof( base_load_table ));
+        memcpy(VOIDP(apCaseLoad), base_load_table, sizeof( base_load_table ));
         apSelectOnly[ FTYP_COMMENT] = mLoad_Comment;
         apSelectOnly[ FTYP_SELECT ] = \
         apCaseLoad[   FTYP_SELECT ] = mLoad_Select;
@@ -1142,8 +1083,8 @@ mLoad_Case(templ_t* pT, macro_t* pMac, char const ** ppzScan)
      *
      *  Also, make sure the CASE macro knows where the end is.
      */
-    pMac->md_end_idx = \
-    current_case.pSelect->md_sib_idx = (pEsacMac - pT->td_macros);
+    pMac->md_end_idx =
+        current_case.pSelect->md_sib_idx = (int)(pEsacMac - pT->td_macros);
 
     /*
      *  Restore any enclosing CASE function's context.
@@ -1173,7 +1114,7 @@ mLoad_Case(templ_t* pT, macro_t* pMac, char const ** ppzScan)
 static bool
 selection_type_complete(templ_t * tpl, macro_t * mac, char const ** psrc)
 {
-    char const * src = (char*)mac->md_txt_off;
+    char const * src = (char *)mac->md_txt_off;
     mac_func_t fcode = FTYP_SELECT_COMPARE_FULL;
 
     /*
@@ -1294,7 +1235,7 @@ static macro_t *
 mLoad_Select(templ_t * tpl, macro_t * mac, char const ** pscan)
 {
     char const *  sel_arg;
-    long          arg_len = mac->md_res; /* macro len  */
+    long          arg_len = (long)mac->md_res; /* macro len  */
 
     (void)pscan;
     /*
@@ -1308,7 +1249,7 @@ mLoad_Select(templ_t * tpl, macro_t * mac, char const ** pscan)
     if (selection_type_complete(tpl, mac, &sel_arg))
         goto selection_done;
 
-    arg_len -= (intptr_t)sel_arg - mac->md_txt_off;
+    arg_len -= (intptr_t)(sel_arg - mac->md_txt_off);
     if (arg_len <= 0)
         AG_ABEND_IN(tpl, mac, LD_SEL_INVAL);
 
@@ -1334,13 +1275,13 @@ mLoad_Select(templ_t * tpl, macro_t * mac, char const ** pscan)
     {
         char *       dest   = tpl->td_scan;
         char const * svdest = dest;
-        mac->md_txt_off = (dest - tpl->td_text);
+        mac->md_txt_off = (uintptr_t)(dest - tpl->td_text);
         if (mac->md_code == FTYP_SELECT_EQUIVALENT) {
             do  {
-                *(dest++) = toupper((uint8_t)*(sel_arg++));
+                *(dest++) = (char)toupper((uint8_t)*(sel_arg++));
             } while (--arg_len > 0);
         } else {
-            memcpy(dest, sel_arg, arg_len);
+            memcpy(dest, sel_arg, (size_t)arg_len);
             dest += arg_len;
         }
         *(dest++) = NUL;
@@ -1352,15 +1293,15 @@ mLoad_Select(templ_t * tpl, macro_t * mac, char const ** pscan)
          * process the string (backslash fixup).
          */
         if ((*svdest == '"') || (*svdest == '\''))
-            span_quote((void *)svdest);
+            span_quote(VOIDP(svdest));
     }
 
  selection_done:
     /*
      *  Link this selection macro to the list of selectors for CASE.
      */
-    current_case.pSelect->md_sib_idx = (mac - tpl->td_macros);
-    current_case.pSelect = (macro_t*)mac;
+    current_case.pSelect->md_sib_idx = (int)(mac - tpl->td_macros);
+    current_case.pSelect = (macro_t *)mac;
 
     return mac + 1;
 }
@@ -1373,13 +1314,15 @@ void
 mUnload_Select(macro_t * mac)
 {
     if (mac->md_pvt != NULL) {
-        regex_t * regexp = (regex_t*)mac->md_pvt;
+        regex_t * regexp = (regex_t *)mac->md_pvt;
         regfree(regexp);
         AGFREE(regexp);
     }
 }
 
-/*
+/**
+ * @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
