@@ -1,6 +1,7 @@
-/*  -*- Mode: C -*-  */
 
-/* printf.c --- printf clone for argv arrays
+/***
+ * @file printf.c
+ * --- printf clone for argv arrays
  * Copyright (C) 1998, 1999, 2000, 2002 Gary V. Vaughan
  * Originally by Gary V. Vaughan, 1998
  * This file is part of Snprintfv
@@ -16,8 +17,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses>.
  *
  * As a special exception to the GNU General Public License, if you
  * distribute this file as part of a program that also links with and
@@ -31,7 +31,7 @@
 #  include <config.h>
 #endif
 
-#include <unistd.h>		/* for the write(2) call */
+#include <unistd.h>             /* for the write(2) call */
 
 #ifdef HAVE_ASSERT_H
 #  include <assert.h>
@@ -59,21 +59,22 @@
 #  endif
 #endif /* SNV_LIBRARY_BUILD */
 
-#define EOS			'\0'
-#define SNV_CHAR_SPEC		'%'
-#define SNV_ESC_SPEC		'\\'
+#define EOS                     '\0'
+#define SNV_CHAR_SPEC           '%'
+#define SNV_ESC_SPEC            '\\'
 
 /* Functions to manage mapping of spec chars to handlers. */
 SNV_INLINE unsigned spec_hash (unsigned spec);
 SNV_INLINE void spec_init (void);
 SNV_INLINE spec_entry *spec_lookup (unsigned spec);
 static void spec_insert (spec_entry * pentry);
-static int do_printfv (STREAM *stream, const char *format, union printf_arg const args[]);
+static int do_printfv (STREAM *stream, const char *format,
+                       union printf_arg const args[]);
 
 /* FIXME:  We are assuming an ASCII character set where all the
            printable characters are between SPACE and DEL. */
-#define ASCII_DEL	(int)'\177'
-#define ASCII_SPACE	(int)' '
+#define ASCII_DEL       (int)'\177'
+#define ASCII_SPACE     (int)' '
 
 #define IS_MODIFIER(spec)  (!((spec)->fmt))
 
@@ -94,7 +95,7 @@ spec_hash (unsigned spec)
 static void
 spec_init (void)
 {
-  static snv_bool_t is_init = SNV_FALSE;
+  static bool is_init = false;
 
   if (!is_init)
     {
@@ -103,12 +104,12 @@ spec_init (void)
 
       memset (spec_table, 0, sizeof (spec_table));
       for (ix = 0; snv_default_spec_table[ix].spec_key != EOS; ix++)
-	{
-	  unsigned hash = spec_hash (snv_default_spec_table[ix].spec_key);
-	  spec_table[hash] = snv_default_spec_table + ix;
-	}
+        {
+          unsigned hash = spec_hash (snv_default_spec_table[ix].spec_key);
+          spec_table[hash] = snv_default_spec_table + ix;
+        }
 
-      is_init = SNV_TRUE;
+      is_init = true;
     }
 }
 
@@ -145,7 +146,8 @@ spec_lookup (unsigned spec)
  * %spec_entry with the information on the function if it was.
  **/
 spec_entry *
-register_printf_function (unsigned spec, printf_function *fmt, printf_arginfo_function *arg)
+register_printf_function (unsigned spec, printf_function *fmt,
+                          printf_arginfo_function *arg)
 {
   spec_entry *new, *old;
   old = spec_lookup (spec);
@@ -191,7 +193,7 @@ call_argtype_function (
            *  Here, we ensure that there are "argindex + 1" entries in
            *  that array.
            */
-          *argtypes = snv_renew (int, *argtypes, argindex + 1);
+          *argtypes = snv_renew (int, *argtypes, (argindex + 1));
 
           /*
            *  IF there are more entries that follow the current argument
@@ -201,7 +203,7 @@ call_argtype_function (
            */
           if (pinfo->argc < argindex)
             memset(*argtypes + pinfo->argc, PA_UNKNOWN,
-                   (argindex - pinfo->argc) * sizeof(**argtypes));
+                   (size_t)(argindex - pinfo->argc) * sizeof(**argtypes));
 
           pinfo->argc = argindex + 1;
         }
@@ -217,21 +219,21 @@ call_argtype_function (
 
       if (pinfo->argc > argindex)
         n = spec->arg(pinfo, (size_t) (pinfo->argc - argindex),
-		      *argtypes + argindex);
+                      *argtypes + argindex);
       else
         n = spec->arg(pinfo, (size_t)0, NULL);
 
       if (n < 0)
-	return n;
+        return n;
       if (argindex + n > pinfo->argc)
         {
           int new_ct = argindex + n;
-	  *argtypes = snv_renew (int, *argtypes, new_ct);
+          *argtypes = snv_renew (int, *argtypes, new_ct);
           memset(*argtypes + pinfo->argc, PA_UNKNOWN,
-                 (new_ct - pinfo->argc) * sizeof(**argtypes));
-	  pinfo->argc = argindex + n;
-	  /* Call again... */
-	  pinfo->argindex = save_argindex;
+                 (size_t)(new_ct - pinfo->argc) * sizeof(**argtypes));
+          pinfo->argc = argindex + n;
+          /* Call again... */
+          pinfo->argindex = save_argindex;
           pinfo->format   = save_format;
           pinfo->state    = save_state;
           pinfo->spec     = (unsigned)*(pinfo->format);
@@ -281,14 +283,19 @@ static inline struct printf_info *
 parser_reset (struct printf_info *pinfo)
 {
   pinfo->is_long_double = pinfo->is_char = pinfo->is_short =
-    pinfo->is_long = pinfo->alt = pinfo->space = pinfo->left =
-    pinfo->showsign = pinfo->group = pinfo->wide =
-    pinfo->width = pinfo->spec = 0;
-
-  pinfo->state = SNV_STATE_BEGIN;
-  pinfo->prec = -1;
-  pinfo->dollar = 0;
-  pinfo->pad = ' ';
+  pinfo->is_long  = 0;
+  pinfo->alt      = 0;
+  pinfo->left     = 0;
+  pinfo->showsign = 0;
+  pinfo->group    = 0;
+  pinfo->wide     = 0;
+  pinfo->spec     = 0;
+  pinfo->width    = 0;
+  pinfo->space    = 0;
+  pinfo->state    = SNV_STATE_BEGIN;
+  pinfo->prec     = -1;
+  pinfo->dollar   = 0;
+  pinfo->pad      = ' ';
 
   return pinfo;
 }
@@ -313,7 +320,9 @@ parser_reset (struct printf_info *pinfo)
  * returned.
  **/
 char *
-printf_error (struct printf_info *pinfo, const char *file, int line, const char *func1, const char *func2, const char *func3, const char *error_message)
+printf_error (struct printf_info *pinfo, const char *file, int line,
+              const char *func1, const char *func2, const char *func3,
+              const char *error_message)
 {
   int i;
   char *result;
@@ -457,7 +466,7 @@ parse_printf_format (const char *format, int n, int *argtypes)
   else
     printf_last_error = NULL;
 
-  return info.argc;
+  return (size_t)info.argc;
 }
 
 static int
@@ -478,71 +487,71 @@ do_printfv (STREAM *stream, const char *format, union printf_arg const args[])
       int ch = (int) *info.format++;
 
       switch (ch)
-	{
-	case SNV_CHAR_SPEC:
-	  if (*info.format != SNV_CHAR_SPEC)
-	    {
-	      /* We found the start of a format specifier! */
-	      spec_entry *spec;
-	      int status;
-	      int argindex;
+        {
+        case SNV_CHAR_SPEC:
+          if (*info.format != SNV_CHAR_SPEC)
+            {
+              /* We found the start of a format specifier! */
+              spec_entry *spec;
+              int status;
+              int argindex;
 
-	      parser_reset (&info);
-	      do
-		{
-		  /* Until we fill the stream (or get some other
-		     exception) or one of the handlers tells us
-		     we have reached the end of the specifier... */
+              parser_reset (&info);
+              do
+                {
+                  /* Until we fill the stream (or get some other
+                     exception) or one of the handlers tells us
+                     we have reached the end of the specifier... */
 
-		  /* ...lookup the handler associated with the char
-		     we are looking at in the format string... */
-		  spec = spec_lookup ((unsigned)*(info.format));
-		  if (spec == NULL)
-		    {
-		      PRINTF_ERROR (&info, "unregistered specifier");
-		      goto error;
-		    }
+                  /* ...lookup the handler associated with the char
+                     we are looking at in the format string... */
+                  spec = spec_lookup ((unsigned)*(info.format));
+                  if (spec == NULL)
+                    {
+                      PRINTF_ERROR (&info, "unregistered specifier");
+                      goto error;
+                    }
 
-		  if (!IS_MODIFIER (spec) &&
-		      !(info.state & (SNV_STATE_BEGIN | SNV_STATE_SPECIFIER)))
-		    {
-		      PRINTF_ERROR (&info, "invalid combination of flags");
-		      goto error;
-		    }
+                  if (!IS_MODIFIER (spec) &&
+                      !(info.state & (SNV_STATE_BEGIN | SNV_STATE_SPECIFIER)))
+                    {
+                      PRINTF_ERROR (&info, "invalid combination of flags");
+                      goto error;
+                    }
 
-		  /* ...and call the relevant handler. */
-		  info.spec = (unsigned)*(info.format);
-		  info.extra = spec->user;
-		  info.type = spec->type;
+                  /* ...and call the relevant handler. */
+                  info.spec = (unsigned)*(info.format);
+                  info.extra = spec->user;
+                  info.type = spec->type;
 
-		  status = spec->arg ? (*spec->arg) (&info, (size_t)0, NULL) : 1;
+                  status = spec->arg ? (*spec->arg) (&info, (size_t)0, NULL) : 1;
 
-		  if (status < 0)
-		    goto error;
+                  if (status < 0)
+                    goto error;
 
-		  argindex = info.dollar && !IS_MODIFIER (spec)
-		    ? info.dollar - 1 : info.argindex;
+                  argindex = info.dollar && !IS_MODIFIER (spec)
+                    ? info.dollar - 1 : info.argindex;
 
-		  info.format++;
-		  info.argc = MAX (info.argc, argindex + status);
-		  if (!info.dollar && !IS_MODIFIER (spec))
-		    info.argindex += status;
-		}
-	      while (info.count >= 0 && IS_MODIFIER (spec));
+                  info.format++;
+                  info.argc = MAX (info.argc, argindex + status);
+                  if (!info.dollar && !IS_MODIFIER (spec))
+                    info.argindex += status;
+                }
+              while (info.count >= 0 && IS_MODIFIER (spec));
 
-	      status = (*spec->fmt) (stream, &info, args + argindex);
+              status = (*spec->fmt) (stream, &info, args + argindex);
 
-	      if (status < 0)
-	        goto error;
+              if (status < 0)
+                goto error;
 
-	      info.count += status;
-	      continue;
-	    }
+              info.count += status;
+              continue;
+            }
 
-	  /* An escaped CHAR_SPEC: ignore it (by falling through). */
-	  ++info.format;
+          /* An escaped CHAR_SPEC: ignore it (by falling through). */
+          ++info.format;
 
-	  /*FALLTHROUGH*/
+          /*FALLTHROUGH*/
 
         default:
           /* Just a character: copy it. */
@@ -686,7 +695,7 @@ stream_printfv (STREAM *stream, const char *format, snv_constpointer const *ap)
           switch (tp & ~PA_FLAG_UNSIGNED)
             {
             case PA_CHAR:
-              args[idx].pa_char = (char) *(const long int *)(ap + idx);
+              args[idx].pa_char = (unsigned char)*(const long int *)(ap + idx);
               break;
 
             case PA_WCHAR:
@@ -799,52 +808,52 @@ stream_vprintf (STREAM *stream, const char *format, va_list ap)
       int ch = (int) *info.format++;
 
       switch (ch)
-	{
-	case SNV_CHAR_SPEC:
-	  if (*info.format != SNV_CHAR_SPEC)
-	    {
-	      /* We found the start of a format specifier! */
-	      spec_entry *spec;
+        {
+        case SNV_CHAR_SPEC:
+          if (*info.format != SNV_CHAR_SPEC)
+            {
+              /* We found the start of a format specifier! */
+              spec_entry *spec;
 
-	      parser_reset (&info);
-	      do
-		{
-		  /* Until we fill the stream (or get some other
-		     exception) or one of the handlers tells us
-		     we have reached the end of the specifier... */
-		  /* ...lookup the handler associated with the char
-		     we are looking at in the format string... */
-		  spec = spec_lookup ((unsigned)*(info.format));
-		  if (spec == NULL)
-		    {
-		      PRINTF_ERROR (&info, "unregistered specifier");
-		      goto error;
-		    }
+              parser_reset (&info);
+              do
+                {
+                  /* Until we fill the stream (or get some other
+                     exception) or one of the handlers tells us
+                     we have reached the end of the specifier... */
+                  /* ...lookup the handler associated with the char
+                     we are looking at in the format string... */
+                  spec = spec_lookup ((unsigned)*(info.format));
+                  if (spec == NULL)
+                    {
+                      PRINTF_ERROR (&info, "unregistered specifier");
+                      goto error;
+                    }
 
-		  if (!IS_MODIFIER (spec) &&
-		      !(info.state & (SNV_STATE_BEGIN | SNV_STATE_SPECIFIER)))
-		    {
-		      PRINTF_ERROR (&info, "invalid combination of flags");
-		      goto error;
-		    }
+                  if (!IS_MODIFIER (spec) &&
+                      !(info.state & (SNV_STATE_BEGIN | SNV_STATE_SPECIFIER)))
+                    {
+                      PRINTF_ERROR (&info, "invalid combination of flags");
+                      goto error;
+                    }
 
-		  /* ...and call the relevant handler.  */
-		  if (call_argtype_function (&info, &argtypes, spec) < 0)
-		    goto error;
+                  /* ...and call the relevant handler.  */
+                  if (call_argtype_function (&info, &argtypes, spec) < 0)
+                    goto error;
 
-		  info.format++;
-		}
-	      while (info.count >= 0 && IS_MODIFIER (spec));
-	      continue;
-	    }
-	  /* An escaped CHAR_SPEC: ignore it (by falling through). */
-	  ++info.format;
+                  info.format++;
+                }
+              while (info.count >= 0 && IS_MODIFIER (spec));
+              continue;
+            }
+          /* An escaped CHAR_SPEC: ignore it (by falling through). */
+          ++info.format;
 
-	  /*FALLTHROUGH*/
+          /*FALLTHROUGH*/
 
-        default:	/* Just a character: ignore it. */
-	  continue;
-	}
+        default:        /* Just a character: ignore it. */
+          continue;
+        }
 
     error:
       /* Get here on error */
@@ -871,63 +880,63 @@ stream_vprintf (STREAM *stream, const char *format, va_list ap)
          Thanks to Robert Lipe <robertlipe@usa.net> for explaining all
          this to me. */
       for (idx = 0; idx < info.argc; idx++)
-	switch (argtypes[idx] & ~PA_FLAG_UNSIGNED)
-	  {
+        switch (argtypes[idx] & ~PA_FLAG_UNSIGNED)
+          {
           case PA_CHAR:
-	    args[idx].pa_char = va_arg (ap, int); /* Promoted.  */
+            args[idx].pa_char = (unsigned char)va_arg (ap, int); /* Promoted */
             break;
 
           case PA_WCHAR:
-	    args[idx].pa_wchar = va_arg (ap, snv_wint_t); /* Promoted.  */
+            args[idx].pa_wchar = (snv_wchar_t)va_arg (ap, snv_wint_t);
             break;
 
           case PA_INT|PA_FLAG_SHORT:
-	    args[idx].pa_short_int = va_arg (ap, int); /* Promoted.  */
+            args[idx].pa_short_int = (short int)va_arg (ap, int);
             break;
 
           case PA_INT:
-	    args[idx].pa_int = va_arg (ap, int);
+            args[idx].pa_int = va_arg (ap, int);
             break;
 
           case PA_INT|PA_FLAG_LONG:
-	    args[idx].pa_long_int = va_arg (ap, long int);
+            args[idx].pa_long_int = va_arg (ap, long int);
             break;
 
           case PA_INT|PA_FLAG_LONG_LONG:
-	    args[idx].pa_long_long_int = va_arg (ap, intmax_t);
+            args[idx].pa_long_long_int = va_arg (ap, intmax_t);
             break;
 
           case PA_FLOAT:
-	    args[idx].pa_float = va_arg (ap, double); /* Promoted.  */
+            args[idx].pa_float = (float)va_arg (ap, double); /* Promoted. */
             break;
 
           case PA_DOUBLE|PA_FLAG_LONG_DOUBLE:
-	    args[idx].pa_long_double = va_arg (ap, long double);
+            args[idx].pa_long_double = va_arg (ap, long double);
             break;
 
           case PA_DOUBLE:
-	    args[idx].pa_double = va_arg (ap, double);
+            args[idx].pa_double = va_arg (ap, double);
             break;
 
           case PA_STRING:
-	    args[idx].pa_string = va_arg (ap, const char *);
+            args[idx].pa_string = va_arg (ap, const char *);
             break;
 
           case PA_WSTRING:
-	    args[idx].pa_wstring = va_arg (ap, const snv_wchar_t *);
+            args[idx].pa_wstring = va_arg (ap, const snv_wchar_t *);
             break;
 
           case PA_POINTER:
-	    args[idx].pa_pointer = va_arg (ap, void *);
+            args[idx].pa_pointer = va_arg (ap, void *);
             break;
 
-	  default:
+          default:
             if (argtypes[idx] & PA_FLAG_PTR)
               args[idx].pa_pointer = va_arg (ap, void *);
             else
               args[idx].pa_long_double = 0.0;
             break;
-	  }
+          }
     }
 
   if (printf_last_error)
@@ -1041,7 +1050,7 @@ snv_vdprintf (int fd, const char *format, va_list ap)
 {
   int result;
   STREAM *out = stream_new (SNV_LONG_TO_POINTER (fd),
-	       		    SNV_UNLIMITED, NULL, snv_fdputc);
+                            SNV_UNLIMITED, NULL, snv_fdputc);
 
   result = stream_vprintf (out, format, ap);
   stream_delete (out);
@@ -1066,7 +1075,7 @@ snv_dprintfv (int fd, const char *format, snv_constpointer const args[])
 {
   int result;
   STREAM *out = stream_new (SNV_LONG_TO_POINTER (fd),
-	       		    SNV_UNLIMITED, NULL, snv_fdputc);
+                            SNV_UNLIMITED, NULL, snv_fdputc);
 
   result = stream_printfv (out, format, args);
   stream_delete (out);
@@ -1267,9 +1276,7 @@ snv_fprintfv (FILE *file, const char *format, snv_constpointer const args[])
  * The value of @ch that has been put in @stream.
  **/
 int
-snv_bufputc (ch, stream)
-     int ch;
-     STREAM *stream;
+snv_bufputc (int ch, STREAM * stream)
 {
   char **ppbuffer = (char **) stream_details (stream);
   **ppbuffer = (char) ch;
@@ -1428,7 +1435,8 @@ snv_vsnprintf (char buffer[], unsigned long limit, const char *format, va_list a
  * an error, when %SNV_ERROR is returned.
  **/
 int
-snv_snprintfv (char buffer[], unsigned long limit, const char *format, snv_constpointer const args[])
+snv_snprintfv (char buffer[], unsigned long limit, const char *format,
+               snv_constpointer const args[])
 {
   int count_or_errorcode;
   STREAM *out = stream_new (&buffer, limit - 1, NULL, snv_bufputc);
@@ -1452,9 +1460,7 @@ snv_snprintfv (char buffer[], unsigned long limit, const char *format, snv_const
  * The value of @ch that has been put in @stream.
  **/
 int
-snv_filputc (ch, stream)
-     int ch;
-     STREAM *stream;
+snv_filputc (int ch, STREAM * stream)
 {
   return filccat ((Filament *) stream_details (stream), ch), ch;
 }
