@@ -1,6 +1,6 @@
 
 /**
- *  @file xml2ag.c
+ * @file xml2ag.c
  *
  *  This is the main routine for xml2ag.
  *
@@ -8,9 +8,9 @@
  *  @{
  */
 /*
- *  xml2ag Copyright (C) 2002-2017 by Bruce Korb - all rights reserved
+ *  xml2ag Copyright (C) 2002-2020 by Bruce Korb - all rights reserved
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2017 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2020 by Bruce Korb - all rights reserved
  *
  *  AutoGen is free software: you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -61,33 +61,13 @@ FILE * ag_pipe_fp;
 
 #define CHUNK_SZ  4096
 
-/* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
-static char *
-loadFile(FILE * fp, size_t * pzSize);
-
-static void
-emitIndentation(void);
-
-static char *
-trim(char const * pzSrc, size_t * pSz);
-
-static xmlNodePtr
-printHeader(xmlDocPtr pDoc);
-
-static void
-printAttrs(xmlAttrPtr pAttr);
-
-static void
-printNode(xmlNodePtr pNode);
-
-static void
-printChildren(xmlNodePtr pNode);
-/* = = = END-STATIC-FORWARD = = = */
 #define TRIM(s,psz) trim( (char const *)(s), (size_t *)(psz) )
 
-extern void fork_ag(char const * pzInput);
-
+extern void       fork_ag(char const * pzInput);
+static char *     loadFile(FILE * fp, size_t * pzSize);
+static xmlNodePtr printHeader(xmlDocPtr pDoc);
+static void       printAttrs(xmlAttrPtr pAttr);
+static void       printChildren(xmlNodePtr pNode);
 
 int
 main(int argc, char ** argv)
@@ -110,6 +90,7 @@ main(int argc, char ** argv)
                 pzFile = *argv;
                 break;
             }
+            /* FALLTHROUGH */
         case 0:
             if (   HAVE_OPT( DEFINITIONS )
                && (strcmp( OPT_ARG( DEFINITIONS ), "-" ) != 0) )
@@ -464,7 +445,7 @@ printNode(xmlNodePtr pNode)
 
 
 static void
-printChildren( xmlNodePtr pNode )
+printChildren(xmlNodePtr pNode)
 {
     while (pNode != NULL) {
         printNode( pNode );
